@@ -18,7 +18,7 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 
-from typing import List, Tuple
+from typing import Dict, List, Tuple
 from dataclasses import dataclass
 import re
 from bs4 import BeautifulSoup, element, Tag
@@ -58,7 +58,7 @@ class SubstitutionPlanMetaTable:
 class SubstitutionPlan:
     """Represents a parsed substitution plan document"""
     # pylint: disable=too-many-instance-attributes
-    courses: List[CourseHeading]
+    courses: Dict[str, CourseHeading]
     meta_table: SubstitutionPlanMetaTable
     date: str
     week: str
